Index: /trunk/ArchTOIPipe/Kernel/asciitoiwtr.cc
===================================================================
--- /trunk/ArchTOIPipe/Kernel/asciitoiwtr.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/asciitoiwtr.cc	(revision 1532)
@@ -40,5 +40,5 @@
 
   double val;
-  int_8 flg;
+  uint_8 flg;
   for (int sn = snb; sn <= sne; sn++) {
     s << sn << "   ";
Index: /trunk/ArchTOIPipe/Kernel/fitstoiwtr.h
===================================================================
--- /trunk/ArchTOIPipe/Kernel/fitstoiwtr.h	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/fitstoiwtr.h	(revision 1532)
@@ -18,5 +18,7 @@
   virtual void afterinit();
 
-  virtual void  addInput(string name, TOI* toi, bool withFlag=false);
+  virtual void  addInput(string name, TOI* toi)
+    {addInput(name,toi,false);}
+  virtual void  addInput(string name, TOI* toi, bool withFlag);
 
   virtual void  run();  
Index: /trunk/ArchTOIPipe/Kernel/toi.cc
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toi.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toi.cc	(revision 1532)
@@ -112,5 +112,5 @@
 double TOI::getData(int i) {
   lock();
-  int_8 flg;
+  uint_8 flg;
   double dat;
   doGetData(i, dat, flg);
@@ -120,5 +120,5 @@
 }
 
-void TOI::getData(int i, double &data,int_8 &flag) {
+void TOI::getData(int i, double &data, uint_8 &flag) {
   lock();
   doGetData(i, data, flag);
@@ -130,5 +130,5 @@
   
 
-void TOI::putData(int i, double value, int_8 flag) {
+void TOI::putData(int i, double value, uint_8 flag) {
   lock();
   doPutData(i, value, flag);
Index: /trunk/ArchTOIPipe/Kernel/toi.h
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toi.h	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toi.h	(revision 1532)
@@ -43,5 +43,5 @@
     
   virtual double        getData(int i);
-  virtual void          getData(int i,double &data,int_8 &flag);
+  virtual void          getData(int i, double &data, uint_8 &flag);
   //RZCMV  virtual DataStatus    getDataError(int i,double &data,double &error,int_4 &flag);
 
@@ -54,5 +54,5 @@
   virtual bool          hasSomeData()=0;
   
-  virtual void          putData(int i, double value, int_8 flag=0);
+  virtual void          putData(int i, double value, uint_8 flag=0);
   //RZCMV  virtual void          putDataError(int i, double value, 
   //		                     double error, int_4 flag=0);
@@ -89,6 +89,6 @@
 #endif
 
-  virtual void          doGetData(int i, double& data, int_8& flag)=0;
-  virtual void          doPutData(int i, double value, int_8 flag=0)=0;
+  virtual void          doGetData(int i, double& data, uint_8& flag)=0;
+  virtual void          doPutData(int i, double value, uint_8 flag=0)=0;
   virtual void          doWontNeedBefore(int i);
 
Index: /trunk/ArchTOIPipe/Kernel/toiprocessor.cc
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toiprocessor.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toiprocessor.cc	(revision 1532)
@@ -286,5 +286,5 @@
 }
 
-void  TOIProcessor::getData(int toiIndex, int i, double &data,int_8 &flag)
+void  TOIProcessor::getData(int toiIndex, int i, double &data, uint_8 &flag)
 {
   TOI* toi = getInputTOI(toiIndex);
@@ -340,5 +340,5 @@
 
 
-void TOIProcessor::putData(int toiIndex, int i, double value, int_8 flg) {
+void TOIProcessor::putData(int toiIndex, int i, double value, uint_8 flg) {
   TOI* toi = getOutputTOI(toiIndex);
   toi->putData(i, value, flg);
Index: /trunk/ArchTOIPipe/Kernel/toiprocessor.h
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toiprocessor.h	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toiprocessor.h	(revision 1532)
@@ -54,5 +54,5 @@
   // utilisees que sur des entrees simples
   double        getData(int toiIndex, int i);
-  void          getData(int toiIndex, int i, double &data,int_8 &flag);
+  void          getData(int toiIndex, int i, double &data, uint_8 &flag);
   
   //RZCMV  double        getError(int toiIndex, int i);
@@ -63,5 +63,5 @@
   void          setNeededHistory(int nsamples); // -1 : disable
 
-  void          putData(int toiIndex, int i, double value, int_8 flag=0);
+  void          putData(int toiIndex, int i, double value, uint_8 flag=0);
   //RZCMV  void          putDataError(int toiIndex, int i, double value, 
   //RZCMV		             double error, int_4 flag=0);
Index: /trunk/ArchTOIPipe/Kernel/toiregwindow.cc
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toiregwindow.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toiregwindow.cc	(revision 1532)
@@ -80,5 +80,5 @@
 #endif
 
-void TOIRegularWindow::doGetData(int i, double & val, int_8 & flg) {
+void TOIRegularWindow::doGetData(int i, double & val, uint_8 & flg) {
   if (isDataAvailNL(i) != DATA_OK) {
     cerr << "TOI::getData : data not available " << i << endl;
@@ -104,6 +104,6 @@
 
 
-void TOIRegularWindow::doPutData(int i, double value, int_8 flag) {
-  int_8 flgdef = 0;
+void TOIRegularWindow::doPutData(int i, double value, uint_8 flag) {
+  uint_8 flgdef = 0;
   if (i0 == -1) {
     data.insert(data.begin(), 1,  defaultValue);
Index: /trunk/ArchTOIPipe/Kernel/toiregwindow.h
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toiregwindow.h	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toiregwindow.h	(revision 1532)
@@ -35,7 +35,7 @@
   l'interface va etre modifiee, NE PAS UTILISER */
 #endif
-  virtual void          doGetData(int i, double & val, int_8 & flg);
+  virtual void          doGetData(int i, double & val, uint_8 & flg);
    
-  virtual void          doPutData(int i, double value, int_8 flag=0);
+  virtual void          doPutData(int i, double value, uint_8 flag=0);
   virtual void          doWontNeedBefore(int i);
 
Index: /trunk/ArchTOIPipe/Kernel/toiseqbuff.cc
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toiseqbuff.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toiseqbuff.cc	(revision 1532)
@@ -37,5 +37,5 @@
   if (flags)  delete[] flags;
   data = new double[buffsize];
-  flags = new int_8[buffsize];
+  flags = new uint_8[buffsize];
   for(int k=0; k<buffsize; k++) {
     data[k] = defaultValue;
@@ -107,5 +107,5 @@
 #endif
 
-void TOISeqBuffered::doGetData(int i, double & val, int_8 & flg) {
+void TOISeqBuffered::doGetData(int i, double & val, uint_8 & flg) {
   if (!started) { 
     cout << " TOISeqBuffered::doGetData() - waitGet() Waiting for start ... " << endl;
@@ -176,5 +176,5 @@
 
 
-void TOISeqBuffered::doPutData(int i, double value, int_8 flag) {
+void TOISeqBuffered::doPutData(int i, double value, uint_8 flag) {
   if (!started) {
     first_in = next_in = i;
Index: /trunk/ArchTOIPipe/Kernel/toiseqbuff.h
===================================================================
--- /trunk/ArchTOIPipe/Kernel/toiseqbuff.h	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/toiseqbuff.h	(revision 1532)
@@ -37,5 +37,5 @@
 protected:
   double* data;
-  int_8*  flags;
+  uint_8*  flags;
   int wsize;
   int buffsize;
@@ -56,7 +56,7 @@
   l'interface va etre modifiee, NE PAS UTILISER ---- */
 #endif
-  virtual void          doGetData(int i, double & val, int_8 & flg);
+  virtual void          doGetData(int i, double & val, uint_8 & flg);
    
-  virtual void          doPutData(int i, double value, int_8 flag=0);
+  virtual void          doPutData(int i, double value, uint_8 flag=0);
   virtual void          doWontNeedBefore(int i);
 
@@ -65,5 +65,5 @@
 
   inline double &       dataRef(int i) { return data[i%buffsize]; }
-  inline int_8 &        flagRef(int i) { return flags[i%buffsize]; }
+  inline uint_8 &        flagRef(int i) { return flags[i%buffsize]; }
   inline bool           isDataDeleted(int i) 
     { return((i < next_in-buffsize-1) ? true : false); }
Index: /trunk/ArchTOIPipe/ProcWSophya/genwproc.cc
===================================================================
--- /trunk/ArchTOIPipe/ProcWSophya/genwproc.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/ProcWSophya/genwproc.cc	(revision 1532)
@@ -89,5 +89,5 @@
 }
 
-TVector<int_8> GenWindowTOIProcessor::GetWFlag(int_4 numtoi)
+TVector<uint_8> GenWindowTOIProcessor::GetWFlag(int_4 numtoi)
 {
   if(numtoi<0 || numtoi>=NbInput)
@@ -108,5 +108,5 @@
 }
  
-int_8 * GenWindowTOIProcessor::GetWFlagPointer(int_4 numtoi)
+uint_8 * GenWindowTOIProcessor::GetWFlagPointer(int_4 numtoi)
 {
   if(numtoi<0 || numtoi>=NbInput)
@@ -117,5 +117,5 @@
 }
 
-void GenWindowTOIProcessor::GetData(int_4 numtoi, int_8 numsample, r_8 & data, int_8 & flag)
+void GenWindowTOIProcessor::GetData(int_4 numtoi, int_8 numsample, r_8 & data, uint_8 & flag)
 {
   if(numtoi<0 || numtoi>=NbInput)
@@ -133,5 +133,5 @@
 ////////////////////////////////////////////////////////////////
 void GenWindowTOIProcessor::PutWData(int numtoi,int_8 numsample
-                                    ,TVector<r_8>& data,TVector<int_8>& flag)
+                                    ,TVector<r_8>& data,TVector<uint_8>& flag)
 {
   if(numtoi<0 || numtoi>=NbOutput || NbOutput<=0)
@@ -151,5 +151,5 @@
 
 void GenWindowTOIProcessor::PutWData(int numtoi,int_8 numsample
-                                    ,r_8 data,int_8 flag)
+                                    , r_8 data, uint_8 flag)
 {
   if(numtoi<0 || numtoi>=NbOutput || NbOutput<=0)
@@ -170,5 +170,5 @@
 /******* cmv routines
 void GenWindowTOIProcessor::PutWData(int_4 numtoi,int_8 numsample
-                                    ,TVector<r_8>& data,TVector<int_8>& flag)
+                                    ,TVector<r_8>& data,TVector<uint_8>& flag)
 {
   if(numtoi<0 || numtoi>=NbOutput || NbOutput<=0)
@@ -186,5 +186,5 @@
 
 void GenWindowTOIProcessor::PutWData(int_4 numtoi,int_8 numsample
-                                    ,r_8 data,int_8 flag)
+                                    ,r_8 data, uint_8 flag)
 {
   if(numtoi<0 || numtoi>=NbOutput || NbOutput<=0)
@@ -253,5 +253,5 @@
 }
 
-TVector<int_8> GenWindowTOIProcessor::GetWFlag(char cw,int_4 numtoi)
+TVector<uint_8> GenWindowTOIProcessor::GetWFlag(char cw,int_4 numtoi)
 // cr='l' fenetre de gauche, 'c' du centre, 'r' de droite, autre = tout
 {
@@ -275,5 +275,5 @@
 }
  
-int_8 * GenWindowTOIProcessor::GetWFlagPointer(char cw,int_4 numtoi,int_4& n)
+uint_8 * GenWindowTOIProcessor::GetWFlagPointer(char cw,int_4 numtoi,int_4& n)
 // cr='l' fenetre de gauche, 'c' du centre, 'r' de droite, autre = tout
 {
@@ -500,14 +500,14 @@
 int i,ii=0;
 r_8   * datatot = WDataIn[0].Data();
-int_8 * flagtot = WFlagIn[0].Data();
+uint_8 * flagtot = WFlagIn[0].Data();
 r_8   * data = GetWDataPointer();
-int_8 * flag = GetWFlagPointer();
+uint_8 * flag = GetWFlagPointer();
 int_4 nl,nc,nr;
 r_8   * datal = GetWDataPointer('l',nl);
-int_8 * flagl = GetWFlagPointer('l',nl);
+uint_8 * flagl = GetWFlagPointer('l',nl);
 r_8   * datac = GetWDataPointer('c',nc);
-int_8 * flagc = GetWFlagPointer('c',nc);
+uint_8 * flagc = GetWFlagPointer('c',nc);
 r_8   * datar = GetWDataPointer('r',nr);
-int_8 * flagr = GetWFlagPointer('r',nr);
+uint_8 * flagr = GetWFlagPointer('r',nr);
 
 cout<<"-------- ks = "<<ks<<endl;
Index: /trunk/ArchTOIPipe/ProcWSophya/genwproc.h
===================================================================
--- /trunk/ArchTOIPipe/ProcWSophya/genwproc.h	(revision 1531)
+++ /trunk/ArchTOIPipe/ProcWSophya/genwproc.h	(revision 1532)
@@ -42,25 +42,25 @@
 
   TVector<r_8> GetWData(int_4 numtoi=0);
-  TVector<int_8> GetWFlag(int_4 numtoi=0);
+  TVector<uint_8> GetWFlag(int_4 numtoi=0);
   r_8 * GetWDataPointer(int_4 numtoi=0);
-  int_8 * GetWFlagPointer(int_4 numtoi=0);
-  void GetData(int_4 numtoi, int_8 numsample, r_8 & data, int_8 & flag);
-  inline void GetData(int_8 numsample, r_8 & data, int_8 & flag)
+  uint_8 * GetWFlagPointer(int_4 numtoi=0);
+  void GetData(int_4 numtoi, int_8 numsample, r_8 & data, uint_8 & flag);
+  inline void GetData(int_8 numsample, r_8 & data, uint_8 & flag)
                       { GetData(0, numsample, data, flag); }
 
   TVector<r_8> GetWData(char cw,int_4 numtoi=0);
-  TVector<int_8> GetWFlag(char cw,int_4 numtoi=0);
+  TVector<uint_8> GetWFlag(char cw,int_4 numtoi=0);
   r_8   * GetWDataPointer(char cw,int_4 numtoi,int_4& n);
-  int_8 * GetWFlagPointer(char cw,int_4 numtoi,int_4& n);
+  uint_8 * GetWFlagPointer(char cw,int_4 numtoi,int_4& n);
   inline   r_8 * GetWDataPointer(char cw,int_4& n)
                  {return GetWDataPointer(cw,0,n);}
-  inline int_8 * GetWFlagPointer(char cw,int_4& n)
+  inline uint_8 * GetWFlagPointer(char cw,int_4& n)
                  {return GetWFlagPointer(cw,0,n);}
 
-  void PutWData(int_4 numtoi,int_8 numsample,TVector<r_8>& data,TVector<int_8>& flag);
-  void PutWData(int_4 numtoi,int_8 numsample,r_8 data,int_8 flag);
-  inline void PutWData(int_8 numsample,TVector<r_8>& data,TVector<int_8>& flag)
+  void PutWData(int_4 numtoi,int_8 numsample,TVector<r_8>& data,TVector<uint_8>& flag);
+  void PutWData(int_4 numtoi,int_8 numsample,r_8 data,uint_8 flag);
+  inline void PutWData(int_8 numsample,TVector<r_8>& data,TVector<uint_8>& flag)
                       {PutWData(0,numsample,data,flag);}
-  inline void PutWData(int_8 numsample,r_8 data,int_8 flag)
+  inline void PutWData(int_8 numsample,r_8 data,uint_8 flag)
                       {PutWData(0,numsample,data,flag);}
 
@@ -100,8 +100,8 @@
 
   vector< TVector<r_8>   > WDataIn;
-  vector< TVector<int_8> > WFlagIn;
+  vector< TVector<uint_8> > WFlagIn;
   vector< bool > WInFlg;
   vector< TVector<r_8>   > WDataOut;
-  vector< TVector<int_8> > WFlagOut;
+  vector< TVector<uint_8> > WFlagOut;
   vector< bool > WOutFlg;
   vector< bool > WPutOutFlg;
Index: /trunk/ArchTOIPipe/ProcWSophya/map2toi.cc
===================================================================
--- /trunk/ArchTOIPipe/ProcWSophya/map2toi.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/ProcWSophya/map2toi.cc	(revision 1532)
@@ -88,5 +88,5 @@
 for(int k=snb;k<=sne;k++) {
 
-  int_8 flg = 0;
+  uint_8 flg = 0;
   double coord1 = getData(0,k);
   double coord2 = getData(1,k);
Index: /trunk/ArchTOIPipe/ProcWSophya/simtoipr.cc
===================================================================
--- /trunk/ArchTOIPipe/ProcWSophya/simtoipr.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/ProcWSophya/simtoipr.cc	(revision 1532)
@@ -114,5 +114,5 @@
     Vector vrec(wrecsize);
 
-    TVector<int_8> vfg(wsize);
+    TVector<uint_8> vfg(wsize);
     int wsz2 = wsize/2;
     // Le debut 
@@ -464,5 +464,5 @@
     int wsz2 = wsize/2;
     Vector vin(wsize);
-    TVector<int_8> vfg(wsize);
+    TVector<uint_8> vfg(wsize);
     int k;
     for(k=0; k<wsize; k++) 
@@ -595,6 +595,6 @@
     double out = 0.;
     double valin = 0.;
-    int_8 fgin = 0;
-    int_8 fgout = 0;
+    uint_8 fgin = 0;
+    uint_8 fgout = 0;
     for(k=snb;k<=sne;k++) {
       out = 0;
@@ -694,5 +694,5 @@
     Vector vin(wsize);
     Vector vout(wsize);
-    TVector<int_8> vfg(wsize);
+    TVector<uint_8> vfg(wsize);
     TVector< complex<r_8> > vfft, vfftmean;
     Vector meanpowerspectra;
@@ -756,5 +756,5 @@
     // 2eme partie, on traite la fin du bloc d'echantillons si necessaire
     double inval;
-    int_8 inflg;
+    uint_8 inflg;
     if (klast < sne) 
       for(k=klast+1; k<=sne; k++) {
@@ -887,5 +887,5 @@
     Timer tm("SimpleFanOut::run()");
     double valin = 0.;
-    int_8 fgin = 0;
+    uint_8 fgin = 0;
     for(int k=snb;k<=sne;k++) {
       for(int i=0;i<nb_input;i++) {
Index: /trunk/ArchTOIPipe/Processors/nooppr.cc
===================================================================
--- /trunk/ArchTOIPipe/Processors/nooppr.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Processors/nooppr.cc	(revision 1532)
@@ -60,6 +60,6 @@
   double * vin = NULL;
   double * vin2 = NULL;
-  int_8 * vfg = NULL;
-  int_8 * vfg2 = NULL;
+  uint_8 * vfg = NULL;
+  uint_8 * vfg2 = NULL;
   try {
     // Le debut
@@ -70,8 +70,8 @@
     if (wsize > 1) {
       vin = new double[wsize];
-      vfg = new int_8[wsize];
+      vfg = new uint_8[wsize];
       if (fgin2) {
 	vin2 = new double[wsize];
-	vfg2 = new int_8[wsize];
+	vfg2 = new uint_8[wsize];
       }
     
@@ -98,5 +98,5 @@
     // 2eme partie, on traite la fin du bloc d'echantillons si necessaire
     double inval;
-    int_8 inflg;
+    uint_8 inflg;
     if (klast < sne) 
       for(k=klast+1; k<=sne; k++) {
Index: /trunk/ArchTOIPipe/TestPipes/tgenw.cc
===================================================================
--- /trunk/ArchTOIPipe/TestPipes/tgenw.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/TestPipes/tgenw.cc	(revision 1532)
@@ -63,5 +63,5 @@
     // Cas ou on a un step de 1
     r_8 data;
-    int_8 flag;
+    uint_8 flag;
     GetData(ks,data,flag);
     PutWData(ks,data,flag);
@@ -80,5 +80,5 @@
     // et on ne peut donc pas ecrire autant de valeurs en sortie que lues en entree
     TVector<r_8> data;
-    TVector<int_8> flag;
+    TVector<uint_8> flag;
     int_4 ideb,ifin,isndeb;
     if(GetWStep()<=GetWSize()/2+1) {
@@ -125,5 +125,5 @@
     // CA NE MARCHE PAS DANS CE CAS
     TVector<r_8> data;
-    TVector<int_8> flag;
+    TVector<uint_8> flag;
     int_4 ideb=0, ifin=GetWSize()-1;
     int_8 ilen = EndSampleNum() - StartSampleNum() + 1;

Index: /trunk/ArchTOIPipe/Kernel/fitstoiwtr.cc
===================================================================
--- /trunk/ArchTOIPipe/Kernel/fitstoiwtr.cc	(revision 1531)
+++ /trunk/ArchTOIPipe/Kernel/fitstoiwtr.cc	(revision 1532)
@@ -80,5 +80,5 @@
       cout << " Column[" << ck << "] -Flag- Name=" << coln[ck] << endl;
       coltypes[ck] = "1J";
-      colunits[ck] = "Int_8Flag";
+      colunits[ck] = "UInt_8Flag";
     }
   }
@@ -103,6 +103,6 @@
 
   double* tabdata = new double[ndata];
-  int_8* tabflag = new int_8[ndata]; 
-  long* tabflagl = (long*) tabflag; // il faut int_8 == long, 
+  uint_8* tabflag = new uint_8[ndata]; 
+  long* tabflagl = (long*) tabflag; // il faut uint_8 == long, 
                                     // c'est long long dans sophya
   bool* tabck = new bool[ndata];
@@ -118,5 +118,5 @@
     //  cout << " DBG-A-FitsWriter::run()" << sn << endl;
     try {
-      int_8 out_flg;
+      uint_8 out_flg;
       double out_val;
       for (i=0; i<ndata; i++) {
@@ -124,5 +124,5 @@
 	  getData(i,sn, out_val, out_flg);
 	  tabdata[i] = out_val;
-	  tabflag[i] = out_flg;
+	  tabflag[i] = out_flg & 0xFFFFFFFF;
 	}
       }